//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraInfo](index.md)/[roundWind](round-wind.md)

# roundWind

[common]\
abstract val [roundWind](round-wind.md): [Wind](../../mahjongutils.models/-wind/index.md)?

场风
